@@ -3,9 +3,9 @@
 	fd.h -- UNIX file descriptor bookkeeping and handling
 	Copyright (C) 2004  Wessel Dankers <wsl@uvt.nl>
 
-	This program is free software; you can redistribute it and/or modify
+	This program is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation; either version 2 of the License, or
+	the Free Software Foundation, either version 3 of the License, or
 	(at your option) any later version.
 
 	This program is distributed in the hope that it will be useful,
@@ -14,11 +14,10 @@
 	GNU General Public License for more details.
 
 	You should have received a copy of the GNU General Public License
-	along with this program; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-	$Id: fd.h 23144 2007-12-21 15:36:48Z wsl $
-	$URL: https://infix.uvt.nl/its-id/trunk/sources/fair-0.5.1/src/fd.h $
+	$Id: fd.h 223 2011-12-02 10:53:44Z wsl $
+	$URL: https://svn.fair.uvt.nl/branches/0.5/src/fd.h $
 
 ******************************************************************************/
 
